@@ -6,7 +6,10 @@ Created on Sep 18, 2009
 
 import os
 import re
+import shutil
+import subprocess
 import sys
+from contextlib import suppress
 from .sssdoptions import SSSDOptions
 from .ipachangeconf import SSSDChangeConf
 
@@ -1001,20 +1004,12 @@ class SSSDConfig(SSSDChangeConf):
         with open(configfile, 'r') as fd:
             try:
                 self.readfp(fd)
-            except:
+            except Exception:
                 raise ParsingError
 
         self.configfile = configfile
         self.initialized = True
 
-        try:
-            if int(self.get('sssd', 'config_file_version')) != self.API_VERSION:
-                raise ParsingError("Wrong config_file_version")
-        except TypeError:
-            # This happens when config_file_version is missing. We
-            # can assume it is the default version and continue.
-            pass
-
     def new_config(self):
         """
         Initialize the SSSDConfig object with the defaults from the schema.
@@ -1071,6 +1066,14 @@ class SSSDConfig(SSSDChangeConf):
             output = self.dump(self.opts)
             of.write(output)
         os.umask(old_umask)
+        service_user = ""
+        ret = subprocess.run(["systemctl", "show", "sssd", "--value", "--property", "User"], capture_output=True, text=True)
+        if ret.returncode == 0:
+            service_user = ret.stdout.strip()
+        if service_user == "":
+            service_user = "root"
+        with suppress(PermissionError):
+            shutil.chown(outputfile, service_user, service_user)
 
     def list_active_services(self):
         """
@@ -1373,23 +1376,27 @@ class SSSDConfig(SSSDChangeConf):
             raise NotInitializedError
 
         if (self.has_option('sssd', 'domains')):
-            active_domains = striplist(self.get('sssd', 'domains').split(','))
-            domain_dict = dict.fromkeys(active_domains)
+            sssd_domains = striplist(self.get('sssd', 'domains').split(','))
+            domain_dict = dict.fromkeys(sssd_domains)
             if '' in domain_dict:
                 del domain_dict['']
-
-            # Remove any entries in this list that don't
-            # correspond to an active domain, for integrity
-            configured_domains = self.list_domains()
-            for dom in list(domain_dict):
-                if dom not in configured_domains:
-                    del domain_dict[dom]
-
-            active_domains = list(domain_dict)
+            sssd_domains = list(domain_dict)
         else:
-            active_domains = []
+            sssd_domains = []
 
-        return active_domains
+        domains = self.list_domains()
+        for dom in self.list_domains():
+            # Remove explicitly enabled from the list
+            if self.has_option('domain/%s' % dom, 'enabled'):
+                if self.get('domain/%s' % dom, 'enabled') == 'false':
+                    domains.remove(dom)
+                    if dom in sssd_domains:
+                        sssd_domains.remove(dom)
+            else:
+                if dom not in sssd_domains:
+                    domains.remove(dom)
+
+        return domains
 
     def list_inactive_domains(self):
         """
@@ -1407,12 +1414,24 @@ class SSSDConfig(SSSDChangeConf):
             raise NotInitializedError
 
         if (self.has_option('sssd', 'domains')):
-            active_domains = striplist(self.get('sssd', 'domains').split(','))
+            sssd_domains = striplist(self.get('sssd', 'domains').split(','))
+            domain_dict = dict.fromkeys(sssd_domains)
+            if '' in domain_dict:
+                del domain_dict['']
+            sssd_domains = list(domain_dict)
         else:
-            active_domains = []
+            sssd_domains = []
+
+        domains = self.list_domains()
+        for dom in self.list_domains():
+            # Remove explicitly enabled from the list
+            if self.has_option('domain/%s' % dom, 'enabled'):
+                if self.get('domain/%s' % dom, 'enabled') == 'true':
+                    domains.remove(dom)
+            else:
+                if dom in sssd_domains:
+                    domains.remove(dom)
 
-        domains = [x for x in self.list_domains()
-                   if x not in active_domains]
         return domains
 
     def list_domains(self):
